.. currentmodule:: pynsitu

#############
API reference
#############

This page provides an auto-generated summary of pynsitu's API. For more details
and examples, refer to the relevant chapters in the main part of the
documentation.

..
  .. note::

    A note

events
======

Module handling helpful classes to keep track of an experimental campaign timeline

.. automodule:: pynsitu.events
  :members:

maps
====

Module for map generation (cartopy, folium)

.. automodule:: pynsitu.maps
  :members:

geo
===

Module with pandas and xarray accessors for the analysis of geographically referenced data

.. automodule:: pynsitu.geo
  :members:

tseries
=======

Module with pandas and xarray accessors for time series analysis

.. automodule:: pynsitu.tseries
  :members:

seawater
========

Module with pandas and xarray accessors for data containing seawater information

.. automodule:: pynsitu.seawater
  :members:

drifters
========

Drifter specific data analysis

.. automodule:: pynsitu.drifters
  :members: